==> cheddar-osate2_1.0.0.201901081024.jar: src/cheddar/aadl/To_Resource.java <==
package cheddar.aadl;

import org.osate.aadl2.instance.ComponentInstance;

import cheddar.adl.Address_Space;
import cheddar.adl.Generic_Resource;
import cheddar.adl.Ipcp_Resource;
import cheddar.adl.Np_Resource;
import cheddar.adl.Objects_Type;
import cheddar.adl.Pcp_Resource;
import cheddar.adl.Pip_Resource;
import cheddar.adl.Resources_Type;
import cheddar.osate2_plugin.Debug;

public class To_Resource {

	static public void Create_Data_Component(cheddar.adl.System result, Cheddar_Id_Generator id,
			ComponentInstance component) {

		String name = component.getFullName().toString();

		Integer priority = Properties_With_Default_Value.getPriority(component);
		Resources_Type rt = Properties_With_Default_Value.getConcurrencyControlProtocol(component);

		String address_space_name = Properties_With_Default_Value.getBoundProcess(component);
		String cpu_name = Properties_With_Default_Value.getBoundProcessor(component);
		if (cpu_name.equals(""))
		{
			Address_Space an_address_space = result.Search_Address_Space(address_space_name);
			cpu_name = an_address_space.getCpuName();
		}

		Generic_Resource gr;

		switch (rt) {
		case Immediate_Priority_Ceiling_Protocol:
			Ipcp_Resource ipcp = new Ipcp_Resource();
			gr = ipcp;
			break;
		case Priority_Inheritance_Protocol:
			Pip_Resource pip = new Pip_Resource();
			gr = pip;
			break;
		case Priority_Ceiling_Protocol:
			Pcp_Resource pcp = new Pcp_Resource();
			gr = pcp;
			break;
		// By default, Resources are No protocol resources
		default:
			Np_Resource np = new Np_Resource();
			gr = np;
			break;
		}

		gr.setcheddarXmlId(id.getAndIncrement());
		gr.setName(name);
		gr.setObjectType(Objects_Type.Resource_Object_Type);

		gr.setAddressSpaceName(address_space_name);
		gr.setCpuName(cpu_name);

		gr.setPriority(priority);
		gr.setProtocol(rt);
		gr.setState(1);

		Debug.Put("add resource " + gr.getName());

		result.resources.add(gr);

	}

}

==> cheddar-osate2_1.0.0.202011071011.jar: src/cheddar/aadl/To_Resource.java <==
package cheddar.aadl;

import org.osate.aadl2.instance.ComponentInstance;

import cheddar.adl.Address_Space;
import cheddar.adl.Generic_Resource;
import cheddar.adl.IPcp_Resource;
import cheddar.adl.Np_Resource;
import cheddar.adl.Objects_Type;
import cheddar.adl.Pcp_Resource;
import cheddar.adl.Pip_Resource;
import cheddar.adl.Resources_Type;
import cheddar.osate2_plugin.Debug;

public class To_Resource {

	static public void Create_Data_Component(cheddar.adl.System result, Cheddar_Id_Generator id,
			ComponentInstance component) {

		String name = component.getInstanceObjectPath().toString();

		Integer priority = Properties_With_Default_Value.getPriority(component);
		Resources_Type rt = Properties_With_Default_Value.getConcurrencyControlProtocol(component);

		String address_space_name = Properties_With_Default_Value.getBoundProcess(component);
		String cpu_name = Properties_With_Default_Value.getBoundProcessor(component);
		if (cpu_name.equals("aadl_component_is_not_bound"))
		{
			Address_Space an_address_space = result.Search_Address_Space(address_space_name);
			cpu_name = an_address_space.getCpuName();
		}

		Generic_Resource gr;

		switch (rt) {
		case Immediate_Priority_Ceiling_Protocol:
			IPcp_Resource ipcp = new IPcp_Resource();
			gr = ipcp;
			break;
		case Priority_Inheritance_Protocol:
			Pip_Resource pip = new Pip_Resource();
			gr = pip;
			break;
		case Priority_Ceiling_Protocol:
			Pcp_Resource pcp = new Pcp_Resource();
			gr = pcp;
			break;
		// By default, Resources are No protocol resources
		default:
			Np_Resource np = new Np_Resource();
			gr = np;
			break;
		}

		gr.setcheddarXmlId(id.getAndIncrement());
		gr.setName(name);
		gr.setObjectType(Objects_Type.Resource_Object_Type);

		gr.setAddressSpaceName(address_space_name);
		gr.setCpuName(cpu_name);

		gr.setPriority(priority);
		gr.setProtocol(rt);
		gr.setState(1);

		Debug.Put("add resource " + gr.getName());

		result.resources.add(gr);

	}

}
